'use strict';

exports.__esModule = true;
exports.bind = undefined;

var _mithril = require('mithril');

var _mithril2 = _interopRequireDefault(_mithril);

var _store = require('./store');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @module bind
 */

/**
 * <p>
 *   Function that binds the component given to part of the state
 *   identified by the path.
 * </p>
 * <p>
 *   The component will be given one attribute when rendered;
 *   <ul>
 *     <li><b>state</b>: Contains the state obtained by this function.</li>
 *   </ul>
 * </p>
 * @function bind
 * @param {*} component - Mithril component that should be bound to the 
 * state.
 * @param {string} path - String path in the usual javascript dot notation that
 * allows the system to find the required data in the state.
 * @returns {Object} Returns a wrapper component that has all the properties
 * necessary to render the subscribed component properly.
 */
var bind = exports.bind = function bind(component, path) {
    if (component.view == null && typeof component !== 'function') {
        throw 'bind(component, path) expects a component, \n            not a vnode.';
    }

    return {
        view: function view() {
            var state = _store.Store.find(path);
            return (0, _mithril2.default)(component, { state: state });
        }
    };
};